bayespy.inference.vmp.nodes.gaussian.GaussianWishartDistribution.compute_message_to_parent
==========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianWishartDistribution.compute_message_to_parent